==> alwaysai-2.3.4.tgz: package/src/infrastructure/system-id.ts <==
import { join } from 'path';
import * as t from 'io-ts';
import { ConfigFile } from '@alwaysai/config-nodejs';
import { CLI_TERSE_ERROR } from '@alwaysai/alwayscli';
import { ALWAYSAI_SYSTEM_ID } from '../environment';
import { SystemId, ALWAYSAI_CLI_EXECUTABLE_NAME } from '../constants';
import { LOCAL_AAI_CFG_DIR } from '../paths';

const props = {
  systemId: t.keyof(SystemId),
};

const codec = t.partial(props);

const CLI_JSON_FILE_NAME = 'alwaysai.cli.json';
const path = join(LOCAL_AAI_CFG_DIR, CLI_JSON_FILE_NAME);

const cliJsonFile = ConfigFile({
  path,
  codec,
  ENOENT: {
    code: CLI_TERSE_ERROR,
    message: `File not found ${CLI_JSON_FILE_NAME}. Run command "${ALWAYSAI_CLI_EXECUTABLE_NAME} config set" to set configuration values.`,
  },
  EACCES: {
    code: CLI_TERSE_ERROR,
    message: `Please ensure the permissions on ${LOCAL_AAI_CFG_DIR} include read and write access for the current user.`,
  },
  initialValue: {},
});

export function setSystemId(systemId: SystemId) {
  return cliJsonFile.update((json) => {
    json.systemId = systemId;
  });
}

export function getSystemId() {
  if (ALWAYSAI_SYSTEM_ID) {
    // When the env var is set return the overridden value without updating the config file.
    // This prevents one-off commands from having side effects.
    if (Object.keys(SystemId).includes(ALWAYSAI_SYSTEM_ID)) {
      return ALWAYSAI_SYSTEM_ID as SystemId;
    }
    throw new Error(`Invalid ALWAYSAI_SYSTEM_ID: ${ALWAYSAI_SYSTEM_ID}`);
  }
  const maybeConfig = cliJsonFile.readIfExists();
  if (!maybeConfig || !maybeConfig.systemId) {
    setSystemId('production');
  }
  const systemId =
    maybeConfig && maybeConfig.systemId ? maybeConfig.systemId : 'production';
  return systemId;
}

==> alwaysai-2.5.1.tgz: package/src/infrastructure/system-id.ts <==
import { join } from 'path';
import * as t from 'io-ts';
import { ConfigFile } from '@alwaysai/config-nodejs';
import { CLI_TERSE_ERROR } from '@alwaysai/alwayscli';
import { ALWAYSAI_SYSTEM_ID } from '../environment';
import { SystemId, ALWAYSAI_CLI_EXECUTABLE_NAME } from '../constants';
import { LOCAL_AAI_CFG_DIR } from '../paths';

const props = {
  systemId: t.keyof(SystemId)
};

const codec = t.partial(props);

const CLI_JSON_FILE_NAME = 'alwaysai.cli.json';
const path = join(LOCAL_AAI_CFG_DIR, CLI_JSON_FILE_NAME);

const cliJsonFile = ConfigFile({
  path,
  codec,
  ENOENT: {
    code: CLI_TERSE_ERROR,
    message: `File not found ${CLI_JSON_FILE_NAME}. Run command "${ALWAYSAI_CLI_EXECUTABLE_NAME} config set" to set configuration values.`
  },
  EACCES: {
    code: CLI_TERSE_ERROR,
    message: `Please ensure the permissions on ${LOCAL_AAI_CFG_DIR} include read and write access for the current user.`
  },
  initialValue: {}
});

export function setSystemId(systemId: SystemId) {
  return cliJsonFile.update((json) => {
    json.systemId = systemId;
  });
}

export function getSystemId() {
  if (ALWAYSAI_SYSTEM_ID) {
    // When the env var is set return the overridden value without updating the config file.
    // This prevents one-off commands from having side effects.
    if (Object.keys(SystemId).includes(ALWAYSAI_SYSTEM_ID)) {
      return ALWAYSAI_SYSTEM_ID as SystemId;
    }
    throw new Error(`Invalid ALWAYSAI_SYSTEM_ID: ${ALWAYSAI_SYSTEM_ID}`);
  }
  const maybeConfig = cliJsonFile.readIfExists();
  if (!maybeConfig || !maybeConfig.systemId) {
    setSystemId('production');
  }
  const systemId =
    maybeConfig && maybeConfig.systemId ? maybeConfig.systemId : 'production';
  return systemId;
}
